<?php

namespace Drupal\extra_siteinfo\Form;

use Drupal\extra_siteinfo\ExtraSiteInfoDBHelper;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class ExtraSiteInfoAdvancedForm extends FormBase {

  /**
   * DB helper
   *
   * @var \Drupal\extra_siteinfo\ExtraSiteInfoDBHelper.
   */
  protected $db_helper;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Constructs a new Get User Session.
   *
   * @param \Drupal\extra_siteinfo\ExtraSiteInfoDBHelper
   *   A Database connection to use for reading database data.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   */
  public function __construct(ExtraSiteInfoDBHelper $db_helper, StateInterface $state) {
    $this->db_helper = $db_helper;
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('extra_siteinfo.db_helper'),
      $container->get('state'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'extra_siteinfo_page_advanced_';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $search = $this->state->get('search');
    $form['extra_siteinfo_advanced'] = [
      '#type' => 'fieldset',
      '#description' => '',
      '#description_display' => 'before',
      '#title' => t('Search'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    ];
    $options = [
      '' => 'Select',
      'node' => 'Content Type',
      'user' => 'User',
      'term' => 'Vocabulary',
    ];
    $form['extra_siteinfo_advanced']['search'] = [
      '#type' => 'select',
      '#title' => $this->t('Search'),
      '#options' => $options,
      '#default_value' => $search
    ];
    $form['extra_siteinfo_advanced']['search_submit'] = [
      '#type' => 'submit',
      '#value' => 'Search',
    ];
    $form['extra_siteinfo_advanced']['clear_submit'] = [
      '#type' => 'submit',
      '#value' => 'Clear',
    ];
    if (!empty($search)) {
      $form['extra_siteinfo_advanced']['report_search'] = [
        '#type' => 'fieldset',
        '#title' => t("Report"),
        '#collapsible' => FALSE,
        '#collapsed' => FALSE,
      ];
      $data = [];
      $helper = \Drupal::service('extra_siteinfo.helper');
      if ($search == "node") {
        $form = $this->getAdvancedExtraSiteInfoOfNode($form, $helper, $search);
//         echo "<pre>"; print_r($data); die;
//         $form['extra_siteinfo_advanced']['report_search']['d'] = [
//           '#theme' => 'extra_siteinfo_page_advanced',
//           '#data' => $data,
//           '#data_count' => '123456'
//         ];
      }
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    foreach ($form_state->getValues() as $key => $value) {}
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $operation = $form_state->getValue('op');
    if ($operation == 'Search') {
      $this->state->set('search', $form_state->getValue('search'));
    }
    if ($operation == 'Clear') {
      $this->state->delete('search');
      $form_state->setRedirect('extra_siteinfo.page_advanced');
    }
  }

  protected function renderSearchData($form, $search) {

    return $form;
  }

  protected function getAdvancedExtraSiteInfoOfNode($form, $helper, $search) {
    $form['extra_siteinfo_advanced']['report_search']['1'] = [
      '#type' => 'table',
      '#header' => ['Total Fields in all Content Types', 'Total Field Storages in all Content Types'],
      '#rows' => [[$helper->getContentTypeCount(), $helper->getFieldStorageNamesCountByType($search)]],
    ];
    $all_field_storages = [];
    foreach ($helper->getFieldStorageNamesByType($search) as $_value) {
      $all_field_storages[] = [$_value];
    }
    $form['extra_siteinfo_advanced']['report_search']['2'] = [
      '#type' => 'table',
      '#header' => ['Field Storages in all Content Types'],
      '#rows' => $all_field_storages,
    ];
//     foreach ($helper->getContentTypeNames($search) as $bundle) {
//        $data[$bundle]['field_definitions_count'] = $helper->getFieldDefinitionNamesCountByType($search, $bundle);
//        $data[$bundle]['field_definitions'] = $helper->getFieldDefinitionNamesByType($search, $bundle);
//     }
    return $form;
  }

}
